@@ -3,14 +3,14 @@ from flask import make_response, request
 import json
 
 
-def serialize(obj):
+def serialize_obj(obj):
     '''Used to convert a class to json'''
     return obj.__dict__
 
 def toJSONResponse(object):
     '''Convert an object to json response'''
     data = object.__dict__
-    response = make_response(json.dumps(data, default = serialize))
+    response = make_response(json.dumps(data, default = serialize_obj))
     response.headers['Content-Type'] = 'application/json'
     ##print(json.dumps(data, default = serialize))
     return response
@@ -29,6 +29,17 @@ def serialise():
     def decorator(funct):
         @functools.wraps(funct)
         def wrapper(*args, **kwargs):
-            return toJSONResponse(funct(*args, **kwargs))
+            output = funct(*args, **kwargs)
+            data = output
+            code = 0
+            # check if a repsonse code is also returned
+            if isinstance(output, tuple):
+                data = output[0]
+                code = output[1]
+            else:
+                code = 200
+            if isinstance(data, str):
+                return data, code
+            return toJSONResponse(data), code
         return wrapper
     return decorator
\ No newline at end of file
